==========
*pyawskit*
==========

.. image:: https://img.shields.io/pypi/v/pyawskit

.. image:: https://img.shields.io/github/license/veltzer/pyawskit

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pyawskit

author: Mark Veltzer

version: 0.1.78

	Mark Veltzer <mark.veltzer@gmail.com>, Copyright © 2016, 2017, 2018, 2019, 2020, 2021, 2022, 2023
